/*
 * bdevid.h - general include for the module loader and probe marshalling code.
 *
 * Copyright 2006-2008 Red Hat, Inc.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author(s): Peter Jones <pjones@redhat.com>
 */

#ifndef BDEVID_PRIV_H
#define BDEVID_PRIV_H 1

#include <bdevid.h>

struct bdevid;
struct bdevid_module;
struct bdevid_probe;

struct bdevid_probe_ops_v1 {
    char *name;
    int (*get_vendor)(struct bdevid_bdev *bdev, char **vendor);
    int (*get_model)(struct bdevid_bdev *bdev, char **model);
    int (*get_unique_id)(struct bdevid_bdev *bdev, char **id);
};

struct bdevid_probe_ops_all {
    union {
        struct bdevid_probe_ops_v1 *ops_v1;
        struct bdevid_probe_ops *ops;
    };
};

struct bdevid {
	char *module_pathz;
	size_t module_pathz_len;

	unsigned int modules_count;
	struct bdevid_module **modules;
};

struct bdevid_module {
	struct bdevid *bdevid;
        uint32_t version;

	char *name;
	void *dlh;

	struct bdevid_module_ops *ops;

	unsigned int probes_count;
	struct bdevid_probe **probes;
};

struct bdevid_probe {
	struct bdevid_module *module;

	char *name;

        struct bdevid_probe_ops_all ops;
};

struct bdevid_sysfs_node;
extern struct bdevid_sysfs_node *bdevid_sysfs_find_node(char *file);
extern void bdevid_sysfs_free_node(struct bdevid_sysfs_node *node);
extern char *bdevid_sysfs_get_name(struct bdevid_sysfs_node *node);
extern char *bdevid_sysfs_get_dir(struct bdevid_sysfs_node *node);

#endif /* BDEVID_PRIV_H */
/*
 * vim:ts=8:sw=4:sts=4:et
 */
